/*
 * This file is part of TechReborn, licensed under the MIT License (MIT).
 *
 * Copyright (c) 2017 TechReborn
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package techreborn.client.gui.upgrades;

import net.minecraft.block.state.IBlockState;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiButton;
import net.minecraft.client.renderer.RenderHelper;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.RayTraceResult;
import net.minecraft.util.math.Vec3d;
import reborncore.common.network.NetworkManager;
import techreborn.client.container.builder.BuiltContainer;
import techreborn.client.gui.GuiBase;
import techreborn.packets.PacketSyncSideConfig;

import java.io.IOException;

import techreborn.client.gui.GuiBase.Layer;

/**
 * Created by Mark on 12/04/2017.
 */
public class GuiSideConfig extends GuiBase {

	TileEntity tileEntity;
	int slotID;

	public GuiSideConfig(EntityPlayer player, TileEntity tile, BuiltContainer container, int slotID) {
		super(player, tile, container);
		this.tileEntity = tile;
		this.slotID = slotID;
	}

	@Override
	public void func_73866_w_() {
		super.func_73866_w_();
		this.field_146292_n.clear();
		int i = 0;
		for (EnumFacing facing : EnumFacing.field_82609_l) {
			field_146292_n.add(new GuiButton(facing.func_176745_a(), field_147003_i + 150, field_147009_r + i++ * 23 + 22, 20, 20, "✓"));
		}
	}

	@Override
	protected void func_146976_a(final float f, final int mouseX, final int mouseY) {
		super.func_146976_a(f, mouseX, mouseY);
		final GuiBase.Layer layer = GuiBase.Layer.BACKGROUND;

	}

	@Override
	protected void func_146979_b(final int mouseX, final int mouseY) {
		super.func_146979_b(mouseX, mouseY);
		final GuiBase.Layer layer = GuiBase.Layer.FOREGROUND;
		int offset = 10;
		RenderHelper.func_74519_b();
		RenderHelper.func_74520_c();
		for (EnumFacing facing : EnumFacing.field_82609_l) {
			BlockPos pos = tileEntity.func_174877_v().func_177972_a(facing);
			IBlockState state = tileEntity.func_145831_w().func_180495_p(pos);
			ItemStack stack = state.func_177230_c().getPickBlock(state, new RayTraceResult(new Vec3d(0, 0, 0), facing, pos), tileEntity.func_145831_w(), pos, Minecraft.func_71410_x().field_71439_g);
			if (stack != null && !stack.func_190926_b() && stack.func_77973_b() != null) {
				drawCentredString(stack.func_82833_r() + " - " + facing.func_176610_l(), offset += 22, 4210752, layer);
				field_146296_j.func_175042_a(stack, 10, offset - 2);
			} else {
				drawCentredString(state.func_177230_c().func_149732_F() + " - " + facing.func_176610_l(), offset += 22, 4210752, layer);
			}
		}
	}

	@Override
	protected void func_146284_a(GuiButton button) throws IOException {
		super.func_146284_a(button);
		NetworkManager.sendToServer(new PacketSyncSideConfig(slotID, button.field_146127_k, tileEntity.func_174877_v()));
		Minecraft.func_71410_x().func_147108_a(null);
	}

	@Override
	protected void drawTitle() {
		drawCentredString("Side Configuration", 6, 4210752, Layer.FOREGROUND);
	}

	@Override
	public boolean tryAddUpgrades() {
		return false;
	}

	@Override
	public boolean drawPlayerSlots() {
		return false;
	}
}
