package techreborn.tiles;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.item.crafting.IRecipe;
import net.minecraft.item.crafting.Ingredient;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fml.common.registry.ForgeRegistries;
import org.apache.commons.lang3.tuple.Pair;
import reborncore.api.tile.IInventoryProvider;
import reborncore.common.powerSystem.TilePowerAcceptor;
import reborncore.common.util.Inventory;
import reborncore.common.util.ItemUtils;
import techreborn.client.container.IContainerProvider;
import techreborn.client.container.builder.BuiltContainer;
import techreborn.client.container.builder.ContainerBuilder;

import javax.annotation.Nullable;

/**
 * Created by modmuss50 on 20/06/2017.
 */
public class TileAutoCraftingTable extends TilePowerAcceptor implements IContainerProvider, IInventoryProvider {

	ResourceLocation currentRecipe;

	public Inventory inventory = new Inventory(10, "TileAutoCraftingTable", 64, this);
	public int progress;
	public int maxProgress = 120;
	public int euTick = 10;
	public Pair<ResourceLocation, IRecipe> cachedRecipe;

	public void setCurrentRecipe(ResourceLocation recipe) {
		currentRecipe = recipe;
	}

	@Nullable
	public IRecipe getIRecipe() {
		if (currentRecipe == null) {
			return null;
		}
		if (cachedRecipe == null || !cachedRecipe.getLeft().equals(currentRecipe)) {
			IRecipe recipe = ForgeRegistries.RECIPES.getValue(currentRecipe);
			if (recipe != null) {
				cachedRecipe = Pair.of(currentRecipe, recipe);
				return recipe;
			}
			cachedRecipe = null;
			return null;
		}
		return cachedRecipe.getRight();
	}

	@Override
	public void func_73660_a() {
		super.func_73660_a();
		IRecipe recipe = getIRecipe();
		if (recipe != null) {
			if (progress >= maxProgress) {
				//TODO make the thing
				if (make(recipe)) {
					progress = 0;
				}
			} else {
				if (canMake(recipe)) {
					if (canUseEnergy(euTick)) {
						progress++;
						useEnergy(euTick);
					}
				}
			}
		}
	}

	public boolean canMake(IRecipe recipe) {
		if (recipe.func_194133_a(3, 3)) {
			boolean missingOutput = false;
			for (Ingredient ingredient : recipe.func_192400_c()) {
				if (ingredient != Ingredient.field_193370_a) {
					boolean foundIngredient = false;
					for (int i = 0; i < 9; i++) {
						ItemStack stack = inventory.func_70301_a(i);
						//TODO count if items are used more than once, like 8 wooden planks for a chest
						if (ingredient.apply(stack)) {
							foundIngredient = true;
							break;
						}
					}
					if(!foundIngredient){
						missingOutput = true;
					}
				}
			}
			if (!missingOutput) {
				if (hasOutputSpace(recipe.func_77571_b())) {
					return true;
				}
			}
			return false;
		}
		return false;
	}

	public boolean hasOutputSpace(ItemStack output) {
		ItemStack stack = inventory.func_70301_a(9);
		if (stack.func_190926_b()) {
			return true;
		}
		if (ItemUtils.isItemEqual(stack, output, true, true)) {
			if (stack.func_77976_d() < stack.func_190916_E() + output.func_190916_E()) {
				return true;
			}
		}
		return false;
	}

	public boolean make(IRecipe recipe) {
		if (canMake(recipe)) {
			for (Ingredient ingredient : recipe.func_192400_c()) {
				for (int i = 0; i < 9; i++) {
					ItemStack stack = inventory.func_70301_a(i);
					if (ingredient.apply(stack)) {
						stack.func_190918_g(1); //TODO is this right? or do I need to use it as an actull crafting grid
						break;
					}
				}
			}
			ItemStack output = inventory.func_70301_a(9);
			if (output.func_190926_b()) {
				inventory.func_70299_a(9, recipe.func_77571_b().func_77946_l());
			} else {
				output.func_190917_f(recipe.func_77571_b().func_190916_E());
			}
			return true;
		}
		return false;
	}

	public TileAutoCraftingTable() {
		super();
	}

	@Override
	public double getBaseMaxPower() {
		return 10000;
	}

	@Override
	public double getBaseMaxOutput() {
		return 0;
	}

	@Override
	public double getBaseMaxInput() {
		return 32;
	}

	@Override
	public boolean canAcceptEnergy(EnumFacing enumFacing) {
		return true;
	}

	@Override
	public boolean canProvideEnergy(EnumFacing enumFacing) {
		return false;
	}

	@Override
	public BuiltContainer createContainer(EntityPlayer player) {
		return new ContainerBuilder("autocraftingTable").player(player.field_71071_by).inventory().hotbar()
			.addInventory().tile(this)
			.slot(0, 28, 25).slot(1, 46, 25).slot(2, 64, 25)
			.slot(3, 28, 43).slot(4, 46, 43).slot(5, 64, 43)
			.slot(6, 28, 61).slot(7, 46, 61).slot(8, 64, 61)
			.outputSlot(9, 145, 42)
			.syncIntegerValue(this::getProgress, this::setProgress)
			.syncIntegerValue(this::getMaxProgress, this::setMaxProgress)
			.addInventory().create();
	}

	@Override
	public boolean canBeUpgraded() {
		return false;
	}

	@Override
	public IInventory getInventory() {
		return inventory;
	}

	public int getProgress() {
		return progress;
	}

	public void setProgress(int progress) {
		this.progress = progress;
	}

	public int getMaxProgress() {
		if (maxProgress == 0) {
			maxProgress = 1;
		}
		return maxProgress;
	}

	public void setMaxProgress(int maxProgress) {
		this.maxProgress = maxProgress;
	}
}
